

def mm_to_cm(mm: float) -> float:
    return mm / 10

def mm_to_m(mm: float) -> float:
    return mm / 1000

def mm_to_inch(mm: float) -> float:
    return mm / 25.4


def cm_to_mm(cm: float):
    return cm * 10

def cm_to_inch(cm: float) -> float:
    return cm / 2.54

def cm_to_m(cm: float) -> float:
    return cm / 100


def m_to_mm(m: float) -> float:
    return m * 1000


def inch_to_mm(inch: float) -> float:
    return inch * 25.4

def inch_to_cm(inch: float) -> float:
    return inch * 2.54

def inch_to_m(inch: float) -> float:
    return inch / 39.37


def kmph_to_mph(kmph: float) -> float:
    return kmph / 1.609

def mph_to_kmph(mph: float) -> float:
    return mph * 1.609


def rpm_to_rps(rpm: float) -> float:
    return rpm / 60

def rps_to_rpm(rps: float) -> float:
    return rps * 60

